# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...base_types.types.paginated_response import PaginatedResponse
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
import typing
from .search_results import SearchResults
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class EntitySearchResponse(PaginatedResponse):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.search import Coordinates, EntitySearchResponse, SearchResults
    from sayari.shared_types import Identifier, RiskData, SourceCountInfo, Status

    EntitySearchResponse(
        offset=0,
        limit=1,
        size=QualifiedCount(
            count=64,
            qualifier="eq",
        ),
        next=True,
        data=[
            SearchResults(
                id="mGq1lpuqKssNWTjIokuPeA",
                label="VICTORIA BECKHAM LIMITED",
                degree=67,
                entity_url="/v1/entity/mGq1lpuqKssNWTjIokuPeA",
                pep=False,
                psa_id="695785012897",
                psa_count=3,
                sanctioned=False,
                closed=False,
                company_type="Stock Corporation - Out of State - Stock",
                registration_date="Incorporated 2008-02-28",
                latest_status=Status(
                    status="active",
                    date="2023-08-29",
                ),
                trade_count={"sent": 41, "received": 0},
                type="company",
                identifiers=[
                    Identifier(
                        value="06517802",
                        type="uk_company_number",
                        label="Uk Company Number",
                    ),
                    Identifier(
                        value="6517802",
                        type="unknown",
                        label="Unknown",
                    ),
                    Identifier(
                        value="04781466",
                        type="ca_corporate_id_num",
                        label="Ca Corporate Id Num",
                    ),
                ],
                addresses=[
                    "202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
                    "Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
                    "SAUNDERS BUILDING, 202 HAMMERSMITH ROAD, HAMMERSMITH, LONDON",
                ],
                countries=["GBR", "USA"],
                relationship_count={
                    "linked_to": 3,
                    "has_officer": 2,
                    "shareholder_of": 1,
                    "has_shareholder": 2,
                    "has_registered_agent": 5,
                    "shipper_of": 41,
                    "has_director": 11,
                    "owner_of": 3,
                    "has_founder": 1,
                    "ships_to": 1,
                },
                source_count={
                    "2b618f1996252fe537a6d998ae14c9b2": SourceCountInfo(
                        count=1,
                        label="UK Corporate Registry Confirmation Statements",
                    ),
                    "2b788dbdf9194ed5a5c309386a6516b1": SourceCountInfo(
                        count=28,
                        label="UK HM Revenue & Customs Traders Database",
                    ),
                    "a447a7b622c4ead6e1caf94983dc2337": SourceCountInfo(
                        count=6,
                        label="USA California Secretary of State",
                    ),
                    "ecdfb3f2ecc8c3797e77d5795a8066ef": SourceCountInfo(
                        count=35,
                        label="UK Corporate Registry",
                    ),
                    "e5de7b52cc88ef4cd1a10e201bdf46ee": SourceCountInfo(
                        count=41,
                        label="Vietnam Imports & Exports (January 2023 - Present)",
                    ),
                    "2a4fe9a14e332c8f9ded1f8a457c2b89": SourceCountInfo(
                        count=36,
                        label="UK Land Commercial and Corporate Ownership Data (CCOD)",
                    ),
                    "4ea8bac1bed868e1510ffd21842e9551": SourceCountInfo(
                        count=69,
                        label="UK Persons with Significant Control",
                    ),
                },
                risk={
                    "basel_aml": RiskData(
                        value=4.63,
                        metadata={"country": ["USA"]},
                        level="relevant",
                    ),
                    "cpi_score": RiskData(
                        value=67.0,
                        metadata={"country": ["USA"]},
                        level="relevant",
                    ),
                },
                user_attribute_count={},
                user_record_count=0,
                user_related_entities_count=0,
                user_relationship_count={},
                related_entities_count=67,
                attribute_count={
                    "company_type": 2,
                    "name": 2,
                    "business_purpose": 4,
                    "identifier": 3,
                    "additional_information": 106,
                    "country": 8,
                    "status": 5,
                    "address": 7,
                },
                reference_id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000:4a34442eccf1622995130b194a5d50e7",
                coordinates=[
                    Coordinates(
                        lat=51.49323,
                        lng=-0.22207,
                        address="202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
                    ),
                    Coordinates(
                        lat=51.47943,
                        lng=-0.16859,
                        address="Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
                    ),
                    Coordinates(
                        lat=51.49323,
                        lng=-0.22207,
                        address="SAUNDERS BUILDING, 202 HAMMERSMITH ROAD, HAMMERSMITH, LONDON",
                    ),
                    Coordinates(
                        lat=51.47898,
                        lng=-0.16784,
                        address="Ransome's Dock, 35-37 Parkgate Road, London, SW11 4NP",
                    ),
                    Coordinates(
                        lat=51.493080000000006,
                        lng=-0.22138000000000002,
                        address="Hammersmith Road, London, W6 7DN",
                    ),
                    Coordinates(
                        lat=51.49291,
                        lng=-0.22579,
                        address="202 HAMMERSMITH ROAD UNITED KINGDOM",
                    ),
                ],
                matches={
                    "name": [
                        "<em>VICTORIA</em> <em>BECKHAM</em> <em>LIMITED</em>",
                        "<em>BECKHAM</em> VENTURES <em>LIMITED</em>",
                        "<em>VICTORIA</em> <em>BECKHAM</em> LIMITED",
                        "<em>BECKHAM</em> VENTURES LIMITED",
                    ]
                },
            )
        ],
    )
    """

    offset: int
    next: bool
    data: typing.List[SearchResults]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EntityDetails, EntitySearchResponse=EntitySearchResponse)
update_forward_refs(EntityRelationships, EntitySearchResponse=EntitySearchResponse)
update_forward_refs(RelationshipData, EntitySearchResponse=EntitySearchResponse)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...base_types.types.paginated_response import PaginatedResponse
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
import typing
from .supplier_or_buyer import SupplierOrBuyer
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class BuyerSearchResponse(PaginatedResponse):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.shared_types import Identifier, RiskData, SourceCountInfo
    from sayari.trade import (
        BuyerSearchResponse,
        HsCode,
        SupplierMetadata,
        SupplierOrBuyer,
    )

    BuyerSearchResponse(
        offset=0,
        limit=1,
        size=QualifiedCount(
            count=3,
            qualifier="eq",
        ),
        next=True,
        data=[
            SupplierOrBuyer(
                id="uWNWgzX-Kvp1j-WeXKmLQw",
                label='ООО "ЭРБЭ ЭЛЕКТРОМЕДИЦИН"',
                degree=195,
                entity_url="/v1/entity/uWNWgzX-Kvp1j-WeXKmLQw",
                pep=False,
                psa_id="4398046624552",
                psa_count=1,
                sanctioned=False,
                closed=False,
                translated_label='GESELLSCHAFT MIT BESCHRANKTER HAFTUNG "ERBE ELEKTROMEDIZIN"',
                registration_date="Registered 2008-09-08",
                trade_count={"sent": 0, "received": 192},
                type="company",
                identifiers=[
                    Identifier(
                        value="7705856072",
                        type="ru_inn",
                        label="Ru Inn",
                    ),
                    Identifier(
                        value="5087746065578",
                        type="ru_ogrn",
                        label="Ru Ogrn",
                    ),
                    Identifier(
                        value="770401001",
                        type="ru_kpp",
                        label="Ru Kpp",
                    ),
                    Identifier(
                        value="ФС-99-04-005763",
                        type="ru_license_number",
                        label="Ru License Number",
                    ),
                    Identifier(
                        value="Л016-00110-77/00565584",
                        type="ru_license_number",
                        label="Ru License Number",
                    ),
                ],
                addresses=[
                    "119270, , Г.МОСКВА, УЛ.ХАМОВНИЧЕСКИЙ ВАЛ,Д.12,ЭТ.2,ПОМ.Х,КОМ.15,",
                    "119270, , Г.МОСКВА, УЛ.ХАМОВНИЧЕСКИЙ ВАЛ,Д.12,ЭТ12,ПОМ.Х,КОМ.15,",
                    "119270, ГОРОД МОСКВА, УЛ. ХАМОВНИЧЕСКИЙ ВАЛ, Д. 12, ЭТАЖ 2 ПОМ Х КОМ 15",
                ],
                countries=["RUS"],
                relationship_count={
                    "has_shareholder": 1,
                    "notify_party_of": 133,
                    "has_director": 1,
                    "receives_from": 1,
                    "has_legal_representative": 1,
                },
                source_count={
                    "a9a18eeb901e4376c912e95dc05ceb78": SourceCountInfo(
                        count=9,
                        label="Russia Federal Tax Registry",
                    ),
                    "66dfefb726ae00fde8f09f34c5578d35": SourceCountInfo(
                        count=360,
                        label="Russia Imports & Exports (January 2023 - Present)",
                    ),
                    "e61c3b3478534c110b46cd64c7746e82": SourceCountInfo(
                        count=2,
                        label="Russia Federal Tax Service Financial Statements",
                    ),
                    "56bce0e008204712e302271ddd7b4fb1": SourceCountInfo(
                        count=1,
                        label="Russia Federal Tax Registry (2018)",
                    ),
                },
                risk={
                    "imports_bis_high_priority_items": RiskData(
                        value=1.0,
                        metadata={"origin_shipment_product": ["853669"]},
                        level="elevated",
                    ),
                    "imports_bis_high_priority_items_critical_components": RiskData(
                        value=1.0,
                        metadata={"origin_shipment_product": ["854231"]},
                        level="high",
                    ),
                },
                user_attribute_counts={},
                user_attribute_count={},
                user_record_count=0,
                user_related_entities_count=0,
                user_relationship_count={},
                related_entities_count=195,
                attribute_counts={
                    "name": 3,
                    "business_purpose": 10,
                    "identifier": 7,
                    "additional_information": 2,
                    "country": 2,
                    "shares": 1,
                    "status": 1,
                    "address": 4,
                    "financials": 3,
                },
                attribute_count={
                    "name": 3,
                    "business_purpose": 10,
                    "identifier": 7,
                    "additional_information": 2,
                    "country": 2,
                    "shares": 1,
                    "status": 1,
                    "address": 4,
                    "financials": 3,
                },
                reference_id="56bce0e008204712e302271ddd7b4fb1/5087746065578_7705856072_OOO-ERBE-ELEKTROMEDICIN.html/1552661755844:e39b6745ba02f2a46afdd7ffbd700920",
                metadata=SupplierMetadata(
                    latest_shipment_date="2024-07-10",
                    shipments=6,
                    hs_codes=[
                        HsCode(
                            key="854231",
                            doc_count=6,
                            value="Electronic integrated circuits; processors and controllers, whether or not combined with memories, converters, logic circuits, amplifiers, clock and timing circuits, or other circuits",
                            value_simple="Integrated Circuits",
                        )
                    ],
                ),
            )
        ],
    )
    """

    offset: int
    next: bool
    data: typing.List[SupplierOrBuyer]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EntityDetails, BuyerSearchResponse=BuyerSearchResponse)
update_forward_refs(EntityRelationships, BuyerSearchResponse=BuyerSearchResponse)
update_forward_refs(RelationshipData, BuyerSearchResponse=BuyerSearchResponse)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .hs_code_with_description import HsCodeWithDescription
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TradeTraversalProduct(UniversalBaseModel):
    hs_code: HsCodeWithDescription
    min_date: str
    max_date: str
    arrival_countries: typing.List[str]
    departure_countries: typing.List[str]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class UpdateAttribute(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.attributes import UpdateAttribute

    UpdateAttribute(
        value={
            "street1": "1600 Pennsylvania Avenue NW",
            "city": "Washington DC",
            "state": "Washington DC",
            "postalCode": "20500",
            "country": "US",
        },
        to_date="2024-04-30",
        from_date="2024-01-01",
        date="2024-02-15",
    )
    """

    value: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    value of additional information in JSON format
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    as of date of the attribute
    """

    from_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    start date of the attribute
    """

    to_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    end date of the attribute
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...base_types.types.paginated_response import PaginatedResponse
import typing
from .shipment import Shipment
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ShipmentSearchResponse(PaginatedResponse):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.generated_types import BusinessPurposeProperties
    from sayari.trade import (
        DataSource,
        HsCodeInfo,
        MonetaryValue,
        Shipment,
        ShipmentAddress,
        ShipmentIdentifier,
        ShipmentSearchResponse,
        SourceOrDestinationEntity,
        Weight,
    )

    ShipmentSearchResponse(
        offset=0,
        limit=1,
        size=QualifiedCount(
            count=13,
            qualifier="eq",
        ),
        next=True,
        data=[
            Shipment(
                id="Sdl3aYnJ23Y-3IxgIOkXPA",
                type="shipment",
                buyer=[
                    SourceOrDestinationEntity(
                        id="uWNWgzX-Kvp1j-WeXKmLQw",
                        type="receiver_of",
                        names=[
                            'ООО "ЭРБЭ ЭЛЕКТРОМЕДИЦИН"',
                            'LLC "ERBE ELECTROMEDICAL"',
                            "LIMITED LIABILITY COMPANY ERBE ELECTROMEDITSIN",
                            'GESELLSCHAFT MIT BESCHRANKTER HAFTUNG "ERBE ELEKTROMEDIZIN"',
                        ],
                        risks={
                            "imports_bis_high_priority_items": 1,
                            "imports_bis_high_priority_items_critical_components": 1,
                        },
                        countries=["RUS"],
                        business_purpose=[
                            BusinessPurposeProperties(
                                value="Торговля розничная лекарственными средствами в специализированных магазинах (аптеках)",
                                code="47.73",
                            ),
                            BusinessPurposeProperties(
                                value="Торговля розничная изделиями, применяемыми в медицинских целях, ортопедическими изделиями в специализированных магазинах",
                                code="47.74",
                            ),
                            BusinessPurposeProperties(
                                value="Торговля розничная косметическими и товарами личной гигиены в специализированных магазинах",
                                code="47.75",
                            ),
                            BusinessPurposeProperties(
                                value="Торговля оптовая фармацевтической продукцией",
                                code="46.46",
                            ),
                            BusinessPurposeProperties(
                                code="4646",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                code="4775",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Retail sale of second-hand goods",
                                code="4774",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Other retail sale of new goods in specialized stores",
                                code="4773",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Repair of electronic and optical equipment",
                                code="3313",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Ремонт электронного и оптического оборудования",
                                code="33.13",
                            ),
                        ],
                        address=[
                            {
                                "x": 37.57419598175875,
                                "city": "Г.москва",
                                "y": 55.71777599664301,
                                "country": "RUS",
                                "value": "119270, , MOSCOW, KHAMOVNICHESKY VAL STREET, 12, FLOOR 2, ROOM. X, ROOM 15,",
                            },
                            {
                                "x": 37.57419598175875,
                                "city": "Г.москва",
                                "y": 55.71777599664301,
                                "country": "RUS",
                                "value": "119270, , Г.МОСКВА, УЛ.ХАМОВНИЧЕСКИЙ ВАЛ,Д.12,ЭТ.2,ПОМ.Х,КОМ.15,",
                            },
                            {
                                "x": 37.57419598175875,
                                "city": "Г.москва",
                                "y": 55.71777599664301,
                                "country": "RUS",
                                "value": "119270, , MOSCOW, KHAMOVNICHESKY VAL STREET, 12, FL12, ROOM.H, ROOM 15,",
                            },
                            {
                                "x": 37.57419598175875,
                                "city": "Г.москва",
                                "y": 55.71777599664301,
                                "country": "RUS",
                                "value": "119270, , Г.МОСКВА, УЛ.ХАМОВНИЧЕСКИЙ ВАЛ,Д.12,ЭТ12,ПОМ.Х,КОМ.15,",
                            },
                            {
                                "x": 37.57419598175875,
                                "city": "Город Москва",
                                "y": 55.71777599664301,
                                "country": "RUS",
                                "value": "119270, ГОРОД МОСКВА, УЛ. ХАМОВНИЧЕСКИЙ ВАЛ, Д. 12, ЭТАЖ 2 ПОМ Х КОМ 15",
                            },
                            {
                                "x": 37.57419598175875,
                                "city": "Город Москва",
                                "y": 55.71777599664301,
                                "country": "RUS",
                                "value": "119270, MOSCOW, KHAMOVNICHESKY VAL STREET, BUILDING 12, FLOOR 2 ROM X ROOM 15",
                            },
                            {
                                "x": 37.57419598175875,
                                "city": "Город Москва",
                                "y": 55.71777599664301,
                                "country": "RUS",
                                "value": "119270, CITY MOSCOW, ST. KHAMOVNICHESKY VAL, 12, FLOOR 2 ROM X ROOM 15",
                            },
                            {
                                "x": 37.57419598175875,
                                "city": "Город Москва",
                                "y": 55.71777599664301,
                                "country": "RUS",
                                "value": "119270, ГОРОД МОСКВА, УЛИЦА ХАМОВНИЧЕСКИЙ ВАЛ, ДОМ 12, ЭТАЖ 2 ПОМ Х КОМ 15",
                            },
                        ],
                    )
                ],
                supplier=[
                    SourceOrDestinationEntity(
                        id="yNwunHdFInERKig0Thusgg",
                        type="shipper_of",
                        names=["ERBE ELEKTROMEDIZIN GMBH", "ERBE ELEKTROMED"],
                        risks={
                            "exports_bis_high_priority_items_critical_components": 1,
                            "exports_bis_high_priority_items": 1,
                        },
                        countries=[
                            "DEU",
                            "USA",
                            "MEX",
                            "BRA",
                            "BEL",
                            "ECU",
                            "ITA",
                            "SGP",
                            "CAN",
                            "SWE",
                            "ZAF",
                        ],
                        business_purpose=[
                            BusinessPurposeProperties(
                                value="Activities of holding companies",
                                code="6420",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Activities of head offices",
                                code="7010",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Holdings de instituições não-financeiras",
                                code="64.62-0",
                                standard="CNAE2",
                            ),
                            BusinessPurposeProperties(
                                value="Manufacture of irradiation, electromedical and electrotherapeutic equipment",
                                code="2660",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Manufacture of irradiation, electromedical and electrotherapeutic equipment",
                                code="26.60",
                                standard="NACE2",
                            ),
                            BusinessPurposeProperties(
                                value="Manufacture of medical and dental instruments and supplies",
                                code="3250",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Manufacture of medical and dental instruments and supplies",
                                code="32.50",
                                standard="NACE2",
                            ),
                            BusinessPurposeProperties(
                                value="Repair of electronic and optical equipment",
                                code="3313",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Repair of electronic and optical equipment",
                                code="33.13",
                                standard="NACE2",
                            ),
                            BusinessPurposeProperties(
                                value="Wholesale of other household goods",
                                code="4649",
                                standard="ISIC4",
                            ),
                            BusinessPurposeProperties(
                                value="Wholesale of pharmaceutical goods",
                                code="46.46",
                                standard="NACE2",
                            ),
                        ],
                        address=[
                            {
                                "x": 9.057763185844635,
                                "city": "Tübingen",
                                "state": "bw",
                                "y": 48.49839220684879,
                                "country": "DEU",
                                "value": "WALDHOERNLESTRASSE 17 72072 TUEBINGEN 0 GERMANY",
                            },
                            {
                                "x": 9.057763185844635,
                                "city": "Tuebingen",
                                "y": 48.49839220684879,
                                "country": "DEU",
                                "value": "72072, , TUEBINGEN, WALDHOERNLESTRASSE 17,",
                            },
                            {"value": "WALDHÖRNLESTRAßE 17"},
                            {
                                "x": 9.056857700153852,
                                "city": "Tuebingen",
                                "y": 48.49829144306095,
                                "country": "DEU",
                                "value": "WALDHOERNLESTRASSE TUEBINGEN 72072",
                            },
                            {
                                "x": 9.052098,
                                "city": "Tubingen",
                                "y": 48.522904,
                                "country": "Alemania",
                                "value": "TUBINGEN, ALEMANIA",
                            },
                            {"value": 'ООО "ЭРБЭ ЭЛЕКТРОМЕДИЦИН"'},
                            {
                                "x": 9.060085569236273,
                                "city": "Tubingen",
                                "y": 48.493932657539084,
                                "country": "DEU",
                                "value": "WALDHORNSTRASSE. 17 72072 TBINGEN D ,TUBINGEN ,INFO@ERBE-MED.COM",
                            },
                            {
                                "x": 9.052220000000034,
                                "city": "Tubinga",
                                "y": 48.52266000000003,
                                "country": "Alemania",
                                "value": "TUBINGA, ALEMANIA",
                            },
                            {
                                "value": "WALDHOERNLESTRASSE 17 72072 TUEBING ,TUBINGA ,INFO@ERBE-MED.COM"
                            },
                            {
                                "x": -64.65251108919011,
                                "y": -4.155371602541514,
                                "country": "BRA",
                                "value": "JAPON E5-107 Y AV. AMAZONAS",
                            },
                            {
                                "x": 9.052098,
                                "city": "TUBINGEN",
                                "y": 48.522904,
                                "country": "DEU",
                                "value": "1420-DE-72004 TUBINGEN",
                            },
                            {
                                "x": -78.48600274748468,
                                "city": "Quito",
                                "y": -0.17858591191971498,
                                "country": "Ecuador",
                                "value": "JAPON ES 107 AV. AMAZONAS 170506 QUITO ECUADOR",
                            },
                            {
                                "x": 9.057763185844635,
                                "y": 48.49839220684879,
                                "country": "DEU",
                                "value": "WALDHÖRNLESTRASSE  NUM. EXT. 17",
                            },
                            {
                                "x": 8.9971125,
                                "city": "TUBINGEN",
                                "y": 48.4834617,
                                "country": "Deutschland",
                                "value": "72072 TBINGEN, DEUTSCHLAND",
                            },
                            {
                                "x": 80.0602634,
                                "city": "OKÄND",
                                "y": 6.2482506,
                                "country": "LKA",
                                "value": "OKÄND",
                            },
                            {
                                "x": 80.0602634,
                                "city": "OKÄND",
                                "y": 6.2482506,
                                "country": "LKA",
                                "value": "OKÄND",
                            },
                            {
                                "x": -78.48600822430384,
                                "city": "Quito",
                                "y": -0.1786202845064082,
                                "country": "Ecuador",
                                "value": "JAPON E5-107 Y AV. AMAZONAS QUITO ECUADOR",
                            },
                            {
                                "x": -78.48600822430384,
                                "city": "Quito",
                                "y": -0.1786202845064082,
                                "country": "Ecuador",
                                "value": "JAPON E5 107 Y AV. AMAZONAS QUITO ECUADOR",
                            },
                            {
                                "x": -64.65251108919011,
                                "city": "Es-107av.",
                                "state": "Amazonas",
                                "y": -4.155371602541514,
                                "country": "BRA",
                                "value": "(EMPRESA GRUPOCOR) JAPON ES-107AV. AMAZONAS",
                            },
                            {
                                "x": -66.08332999999993,
                                "y": -3.533329999999978,
                                "country": "BRA",
                                "value": "JAPON ES 107 AV. AMAZONAS",
                            },
                            {
                                "x": -64.65251108919011,
                                "y": -4.155371602541514,
                                "country": "BRA",
                                "value": "JAPON E5 107 Y AV AMAZONAS",
                            },
                        ],
                    )
                ],
                arrival_date="2024-05-14",
                arrival_country=["RUS"],
                departure_country=["DEU"],
                arrival_address=ShipmentAddress(
                    country="RUS",
                ),
                departure_address=ShipmentAddress(
                    country="DEU",
                ),
                product_origin=["DEU"],
                transit_country=[],
                countries=["DEU", "RUS"],
                monetary_value=[
                    MonetaryValue(
                        value=2570.52,
                        currency="USD",
                        context="cost_insurance_and_freight",
                    )
                ],
                weight=[
                    Weight(
                        value=5.5,
                        unit="kilogram",
                        type="net_weight",
                    )
                ],
                identifier=[
                    ShipmentIdentifier(
                        value="10013160/140524/3162513",
                        type="rus_declaration_number",
                    ),
                    ShipmentIdentifier(
                        value="1001325059",
                        type="ru_trade_internal_shipment_id",
                    ),
                ],
                sources=[
                    DataSource(
                        id="66dfefb726ae00fde8f09f34c5578d35",
                        label="Russia Imports & Exports (January 2023 - Present)",
                    )
                ],
                hs_codes=[
                    HsCodeInfo(
                        code="854231",
                        description="Electronic integrated circuits; processors and controllers, whether or not combined with memories, converters, logic circuits, amplifiers, clock and timing circuits, or other circuits",
                    )
                ],
                product_descriptions=[
                    "СХЕМЫ ИНТЕГРАЛЬНЫЕ МОНОЛИТНЫЕ, ЦИФРОВЫЕ, НЕ ЛОМ ЭЛЕКТРООБОРУДОВАНИЯ, НЕ СОДЕРЖАТ КРИПТОГРАФИЧЕСКИХ МОДУЛЕЙ И ПРИЕМОПЕРЕДАТОЧНЫХ УСТР-В, НЕ ДЛЯ ШИФРОВАНИЯ, ГРАЖДАНСКОГО НАЗНАЧЕНИЯ, ДЛЯ ИСПОЛЬЗОВАНИЯ В СОСТАВЕ МЕДИЦИНСКОГО ОБОРУДОВАНИЯ:"
                ],
                record="4337bf42a200a30b90d536c5992167e1/1001325059/1721001600000/0",
            )
        ],
    )
    """

    offset: int
    next: bool
    data: typing.List[Shipment]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from .embedded_entity import EmbeddedEntity
import typing
from .entity_registration_date import EntityRegistrationDate
from .entity_translated_label import EntityTranslatedLabel
from .entity_hs_code import EntityHsCode
from .shipment_arrival import ShipmentArrival
from .shipment_departure import ShipmentDeparture
from .company_type import CompanyType
from .status import Status
from .entity_risk import EntityRisk
import pydantic
from ...generated_types.types.attribute_details import AttributeDetails
from .possibly_same_as import PossiblySameAs
from .referenced_by import ReferencedBy
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.pydantic_utilities import update_forward_refs


class EntityDetails(EmbeddedEntity):
    """
    Additional fields providing more details about an entity
    """

    registration_date: typing.Optional[EntityRegistrationDate] = None
    translated_label: typing.Optional[EntityTranslatedLabel] = None
    hs_code: typing.Optional[EntityHsCode] = None
    shipment_arrival: typing.Optional[ShipmentArrival] = None
    shipment_departure: typing.Optional[ShipmentDeparture] = None
    company_type: typing.Optional[CompanyType] = None
    latest_status: typing.Optional[Status] = None
    risk: EntityRisk = pydantic.Field()
    """
    [Risk factors](/sayari-library/ontology/risk-factors) associated with the entity.
    """

    attributes: typing.Optional[AttributeDetails] = pydantic.Field(default=None)
    """
    Detailed information about the entity's [attributes](/sayari-library/ontology/attributes).
    """

    relationships: typing.Optional["EntityRelationships"] = pydantic.Field(default=None)
    """
    Detailed information about the entity's [relationships](/sayari-library/ontology/relationships).
    """

    possibly_same_as: typing.Optional[PossiblySameAs] = None
    referenced_by: typing.Optional[ReferencedBy] = None
    attribute_counts: typing.Optional[typing.Any] = None
    user_attribute_counts: typing.Optional[typing.Any] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .entity_relationships import EntityRelationships  # noqa: E402
from .relationship_data import RelationshipData  # noqa: E402

update_forward_refs(EntityRelationships, EntityDetails=EntityDetails)
update_forward_refs(RelationshipData, EntityDetails=EntityDetails)
update_forward_refs(EntityDetails)



# This file was auto-generated by Fern from our API Definition.

import typing

SortField = typing.Union[
    typing.Literal[
        "created",
        "-created",
        "saved_resource_id",
        "-saved_resource_id",
        "entity_id",
        "-entity_id",
        "country",
        "-country",
        "latest_status",
        "-latest_status",
        "label",
        "-label",
        "custom_{field name}",
        "-custom_{field name}",
        "receiver_of",
        "-receiver_of",
        "shipper_of",
        "-shipper_of",
        "upstream_entities",
        "-upstream_entities",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .attribute_response_data import AttributeResponseData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class AttributeResponse(UniversalBaseModel):
    """
    OK

    Examples
    --------
    from sayari.attributes import (
        AttributeProperties,
        AttributeResponse,
        AttributeResponseData,
    )

    AttributeResponse(
        data=AttributeResponseData(
            value={
                "street1": "1600 Pennsylvania Avenue NW",
                "city": "Washington DC",
                "state": "Washington DC",
                "postalCode": "20500",
                "country": "US",
            },
            properties=[
                AttributeProperties(
                    editable=True,
                    record_count=0,
                    id="enEwNGF4WDJkTG45dEU2VzZROFFoZ3xhZGRyZXNzfDBwbEVCMHxVNzhzN21yOUVFTThIZ3pwREM3UDFB",
                )
            ],
        ),
    )
    """

    data: AttributeResponseData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...generated_types.types.both_identifier_types import BothIdentifierTypes
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class Identifier(UniversalBaseModel):
    """
    Identifiers associated with the entity.
    """

    value: str
    type: BothIdentifierTypes = pydantic.Field()
    """
    [Identifier Type](/sayari-library/ontology/enumerated-types#identifier-type) or [Weak Identifier Type](/sayari-library/ontology/enumerated-types#weak-identifier-type)
    """

    label: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .notification import Notification
from .project_notification_risk_data import ProjectNotificationRiskData
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ProjectNotificationData(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    The ID of the entity
    """

    resource_id: str = pydantic.Field()
    """
    The ID of the saved resource
    """

    entity_id: str = pydantic.Field()
    """
    The ID of the entity
    """

    notifications: typing.List[Notification]
    custom_fields: typing.Optional[typing.Optional[typing.Any]] = pydantic.Field(default=None)
    """
    <Warning>This property is in beta and is subject to change. It is provided for early access and testing purposes only.</Warning> custom user key/value pairs (key must be prefixed with "custom\_" and value must be "string" type)
    """

    risk_notifications: ProjectNotificationRiskData = pydantic.Field()
    """
    Aggregated risk notifications
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .usage_info import UsageInfo
import pydantic
import typing_extensions
from ...core.serialization import FieldMetadata
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class UsageResponse(UniversalBaseModel):
    usage: UsageInfo = pydantic.Field()
    """
    Usage information for each endpoint
    """

    from_: typing_extensions.Annotated[str, FieldMetadata(alias="from")] = pydantic.Field()
    """
    The start date of the returned usage information.
    """

    to: str = pydantic.Field()
    """
    The end date of the returned usage information.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from .notification_type import NotificationType
from ...generated_types.types.risk import Risk
from ...shared_types.types.risk_value import RiskValue
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class ResourceNotificationData(UniversalBaseModel):
    saved_resource_id: str = pydantic.Field()
    """
    The ID of the saved resource
    """

    project_id: str = pydantic.Field()
    """
    The ID of the project the entity is saved to
    """

    entity_id: str = pydantic.Field()
    """
    The ID of the entity
    """

    type: NotificationType = pydantic.Field()
    """
    The type of notification, currently limited to 'risk'
    """

    field: Risk = pydantic.Field()
    """
    The field that the notification is for
    """

    value: RiskValue = pydantic.Field()
    """
    The previous value of the field
    """

    date: str = pydantic.Field()
    """
    The date the notification was created
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .source import Source
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class GetSourceResponse(Source):
    """
    OK

    Examples
    --------
    from sayari.source import GetSourceResponse

    GetSourceResponse(
        id="f4396e4b8a41d1fd9f09ea94d2ebedb9",
        label="UAE Abu Dhabi Global Market Corporate Registry",
        description="Contains profiles of registered companies. Provides standard company information including name, tax ID, status, address, and business purpose as well as current and former shareholders and directors.",
        country="ARE",
        region="middle_east_&_africa",
        date_added="2022-07-25",
        source_type="company_data",
        record_type="company_record",
        structure="structured",
        source_url="https://www.adgm.com/public-registers",
        pep=False,
        watchlist=False,
    )
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class GetEntityResponse(EntityDetails):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.entity import GetEntityResponse
    from sayari.generated_types import (
        AdditionalInformationData,
        AdditionalInformationInfo,
        AdditionalInformationProperties,
        AddressData,
        AddressInfo,
        AddressProperties,
        AttributeDetails,
        BusinessPurposeData,
        BusinessPurposeInfo,
        BusinessPurposeProperties,
        CompanyTypeData,
        CompanyTypeInfo,
        CompanyTypeProperties,
        CountryData,
        CountryInfo,
        CountryProperties,
        IdentifierData,
        IdentifierInfo,
        IdentifierProperties,
        NameData,
        NameInfo,
        NameProperties,
        StatusData,
        StatusInfo,
        StatusProperties,
    )
    from sayari.shared_types import (
        EntityDetails,
        EntityRelationships,
        Identifier,
        PossiblySameAs,
        PossiblySameAsData,
        PsaEntity,
        RecordDetails,
        ReferencedBy,
        ReferencedByData,
        RelationshipData,
        RelationshipInfo,
        RiskData,
        SourceCountInfo,
        Status,
    )

    GetEntityResponse(
        id="mGq1lpuqKssNWTjIokuPeA",
        label="VICTORIA BECKHAM LIMITED",
        degree=67,
        entity_url="/v1/entity/mGq1lpuqKssNWTjIokuPeA",
        pep=False,
        psa_id="695785012897",
        psa_count=3,
        sanctioned=False,
        closed=False,
        company_type="Stock Corporation - Out of State - Stock",
        registration_date="Incorporated 2008-02-28",
        latest_status=Status(
            status="active",
            date="2023-08-29",
        ),
        trade_count={"sent": 41, "received": 0},
        type="company",
        identifiers=[
            Identifier(
                value="06517802",
                type="uk_company_number",
                label="Uk Company Number",
            ),
            Identifier(
                value="6517802",
                type="unknown",
                label="Unknown",
            ),
            Identifier(
                value="04781466",
                type="ca_corporate_id_num",
                label="Ca Corporate Id Num",
            ),
        ],
        addresses=[
            "202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
            "Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
            "SAUNDERS BUILDING, 202 HAMMERSMITH ROAD, HAMMERSMITH, LONDON",
        ],
        countries=["GBR", "USA"],
        relationship_count={
            "linked_to": 3,
            "has_officer": 2,
            "shareholder_of": 1,
            "has_shareholder": 2,
            "has_registered_agent": 5,
            "shipper_of": 41,
            "has_director": 11,
            "owner_of": 3,
            "has_founder": 1,
            "ships_to": 1,
        },
        source_count={
            "2b618f1996252fe537a6d998ae14c9b2": SourceCountInfo(
                count=1,
                label="UK Corporate Registry Confirmation Statements",
            ),
            "2b788dbdf9194ed5a5c309386a6516b1": SourceCountInfo(
                count=28,
                label="UK HM Revenue & Customs Traders Database",
            ),
            "a447a7b622c4ead6e1caf94983dc2337": SourceCountInfo(
                count=6,
                label="USA California Secretary of State",
            ),
            "ecdfb3f2ecc8c3797e77d5795a8066ef": SourceCountInfo(
                count=35,
                label="UK Corporate Registry",
            ),
            "e5de7b52cc88ef4cd1a10e201bdf46ee": SourceCountInfo(
                count=41,
                label="Vietnam Imports & Exports (January 2023 - Present)",
            ),
            "2a4fe9a14e332c8f9ded1f8a457c2b89": SourceCountInfo(
                count=36,
                label="UK Land Commercial and Corporate Ownership Data (CCOD)",
            ),
            "4ea8bac1bed868e1510ffd21842e9551": SourceCountInfo(
                count=69,
                label="UK Persons with Significant Control",
            ),
        },
        risk={
            "basel_aml": RiskData(
                value=4.63,
                metadata={"country": ["USA"]},
                level="relevant",
            ),
            "cpi_score": RiskData(
                value=67.0,
                metadata={"country": ["USA"]},
                level="relevant",
            ),
        },
        user_attribute_count={},
        user_record_count=0,
        user_related_entities_count=0,
        user_relationship_count={},
        related_entities_count=67,
        attribute_count={
            "company_type": 2,
            "name": 2,
            "business_purpose": 4,
            "identifier": 3,
            "additional_information": 106,
            "country": 8,
            "status": 5,
            "address": 7,
        },
        reference_id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000:4a34442eccf1622995130b194a5d50e7",
        attributes=AttributeDetails(
            additional_information=AdditionalInformationInfo(
                limit=1,
                next="_SjfEipa7hytJ93C1IT_sg",
                size=QualifiedCount(
                    count=106,
                    qualifier="eq",
                ),
                data=[
                    AdditionalInformationData(
                        properties=AdditionalInformationProperties(
                            type="Traded Goods",
                        ),
                        record=[
                            "2b788dbdf9194ed5a5c309386a6516b1/22950249e3df0c33ce05bd54850ba9f3/1672444800000"
                        ],
                        record_count=9,
                        editable=False,
                    )
                ],
            ),
            address=AddressInfo(
                limit=1,
                next="5TPSsmsFxea24_QTyk8o1Q",
                size=QualifiedCount(
                    count=7,
                    qualifier="eq",
                ),
                data=[
                    AddressData(
                        properties=AddressProperties(
                            value="202 HAMMERSMITH ROAD UNITED KINGDOM",
                            house_number="202",
                            road="Hammersmith Road",
                            country="United Kingdom",
                            x=-0.22579,
                            y=51.49291,
                            precision_code="G3",
                            normalized="202 HAMMERSMITH KINGDOM RD UNITED",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1678752000000"
                        ],
                        record_count=5,
                        editable=False,
                    )
                ],
            ),
            business_purpose=BusinessPurposeInfo(
                limit=1,
                next="5fZrn5ZbUyo6d_huc6NlAA",
                size=QualifiedCount(
                    count=4,
                    qualifier="eq",
                ),
                data=[
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="Other amusement and recreation activities n.e.c.",
                            code="9329",
                            standard="ISIC4",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                        editable=False,
                    )
                ],
            ),
            company_type=CompanyTypeInfo(
                limit=1,
                next="iuJ_MCygy24sDCcVkbCATA",
                size=QualifiedCount(
                    count=2,
                    qualifier="eq",
                ),
                data=[
                    CompanyTypeData(
                        properties=CompanyTypeProperties(
                            value="Stock Corporation - Out of State - Stock",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                        editable=False,
                    )
                ],
            ),
            country=CountryInfo(
                limit=1,
                next="_ZTsEnhxCbjokYYWu1kMoQ",
                size=QualifiedCount(
                    count=8,
                    qualifier="eq",
                ),
                data=[
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="address",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=23,
                        editable=False,
                    )
                ],
            ),
            identifier=IdentifierInfo(
                limit=1,
                next="07v3Rsu6x-gDuukFa0jEsw",
                size=QualifiedCount(
                    count=3,
                    qualifier="eq",
                ),
                data=[
                    IdentifierData(
                        properties=IdentifierProperties(
                            value="04781466",
                            type="ca_corporate_id_num",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                        editable=False,
                    )
                ],
            ),
            name=NameInfo(
                limit=1,
                next="5lxpjuZmt31xiCnbDILp0A",
                size=QualifiedCount(
                    count=2,
                    qualifier="eq",
                ),
                data=[
                    NameData(
                        properties=NameProperties(
                            value="BECKHAM VENTURES LIMITED",
                            context="alias",
                            to_date="2014-09-03",
                        ),
                        record=[
                            "2a4fe9a14e332c8f9ded1f8a457c2b89/NGL944625/1560779151522"
                        ],
                        record_count=30,
                        editable=False,
                    )
                ],
            ),
            status=StatusInfo(
                limit=1,
                next="EdC1n7V2lU0oKTokzO_YLw",
                size=QualifiedCount(
                    count=5,
                    qualifier="eq",
                ),
                data=[
                    StatusData(
                        properties=StatusProperties(
                            text="Good",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                        editable=False,
                    )
                ],
            ),
        ),
        relationships=EntityRelationships(
            limit=1,
            next="fzenMMQtpFHx9Cam_2nDndg",
            size=QualifiedCount(
                count=67,
                qualifier="eq",
            ),
            data=[
                RelationshipData(
                    target=EntityDetails(
                        id="zenMMQtpFHx9Cam_2nDndg",
                        label="Victoria Beckham Holdings Limited",
                        degree=17,
                        entity_url="/v1/entity/zenMMQtpFHx9Cam_2nDndg",
                        pep=False,
                        psa_count=0,
                        sanctioned=False,
                        closed=False,
                        company_type="Private Limited Company",
                        registration_date="Incorporated 2017-11-02",
                        latest_status=Status(
                            status="active",
                        ),
                        trade_count={"sent": 0, "received": 0},
                        type="company",
                        identifiers=[
                            Identifier(
                                value="11043864",
                                type="uk_company_number",
                                label="Uk Company Number",
                            )
                        ],
                        addresses=[
                            "35-37 Parkgate Road, London, SW11 4NP",
                            "Hammersmith Road, London",
                            "202 HAMMERSMITH ROAD, LONDON, W6 7DN",
                        ],
                        countries=["GBR"],
                        relationship_count={
                            "shareholder_of": 2,
                            "has_shareholder": 5,
                            "has_registered_agent": 1,
                            "has_director": 9,
                            "linked_to": 7,
                        },
                        source_count={
                            "ecdfb3f2ecc8c3797e77d5795a8066ef": SourceCountInfo(
                                count=34,
                                label="UK Corporate Registry",
                            ),
                            "2b618f1996252fe537a6d998ae14c9b2": SourceCountInfo(
                                count=1,
                                label="UK Corporate Registry Confirmation Statements",
                            ),
                            "4ea8bac1bed868e1510ffd21842e9551": SourceCountInfo(
                                count=147,
                                label="UK Persons with Significant Control",
                            ),
                        },
                        risk={
                            "basel_aml": RiskData(
                                value=3.99,
                                metadata={"country": ["GBR"]},
                                level="relevant",
                            ),
                            "cpi_score": RiskData(
                                value=78.0,
                                metadata={"country": ["GBR"]},
                                level="relevant",
                            ),
                        },
                        user_attribute_count={},
                        user_record_count=0,
                        user_related_entities_count=0,
                        user_relationship_count={},
                        related_entities_count=17,
                        attribute_count={
                            "company_type": 1,
                            "name": 2,
                            "business_purpose": 3,
                            "identifier": 1,
                            "additional_information": 1,
                            "country": 3,
                            "status": 2,
                            "address": 3,
                        },
                        reference_id="ecdfb3f2ecc8c3797e77d5795a8066ef/11043864/1540252800000:40ec7b0310d308ebf9006148b53a2802",
                    ),
                    types={
                        "has_shareholder": [
                            RelationshipInfo(
                                editable=False,
                                record="4ea8bac1bed868e1510ffd21842e9551/56910fae410d43596d5a94fd9405023a/1711843200000",
                                attributes={},
                                acquisition_date="2024-03-31",
                            ),
                            RelationshipInfo(
                                editable=False,
                                record="4ea8bac1bed868e1510ffd21842e9551/06517802/1560176240192",
                                attributes={
                                    "position": [
                                        {
                                            "value": "Has right to appoint and remove directors"
                                        },
                                        {"value": "Owns 75-100% of shares"},
                                        {"value": "Owns 75-100% of voting rights"},
                                    ],
                                    "shares": [{"percentage": 75}],
                                },
                                acquisition_date="2019-06-10",
                            ),
                        ],
                        "linked_to": [
                            RelationshipInfo(
                                editable=False,
                                record="4ea8bac1bed868e1510ffd21842e9551/56910fae410d43596d5a94fd9405023a/1711843200000",
                                attributes={},
                                acquisition_date="2024-03-31",
                            ),
                            RelationshipInfo(
                                editable=False,
                                record="4ea8bac1bed868e1510ffd21842e9551/06517802/1560176240192",
                                attributes={
                                    "position": [
                                        {
                                            "value": "Has right to appoint and remove directors"
                                        },
                                        {"value": "Owns 75-100% of shares"},
                                        {"value": "Owns 75-100% of voting rights"},
                                    ]
                                },
                                acquisition_date="2019-06-10",
                            ),
                        ],
                    },
                    dates=["2017-11-16"],
                    first_observed="2017-11-16",
                    last_observed="2017-11-16",
                )
            ],
        ),
        possibly_same_as=PossiblySameAs(
            limit=1,
            size=QualifiedCount(
                count=3,
                qualifier="eq",
            ),
            next="eyJ0eXBlIjoic2F5YXJpIiwib2Zmc2V0IjoxfQ",
            data=[
                PossiblySameAsData(
                    entity=PsaEntity(
                        id="NGUTEUTI4YZ6R5d56vgNIw",
                        label="BECKHAM VENTURES INC.",
                        degree=3,
                        entity_url="/v1/entity/NGUTEUTI4YZ6R5d56vgNIw",
                        pep=False,
                        psa_id="695785012897",
                        psa_count=3,
                        sanctioned=False,
                        closed=False,
                        company_type="FOREIGN BUSINESS CORPORATION",
                        registration_date=" 2013-01-16",
                        latest_status=Status(
                            status="active",
                            date="2013-01-16",
                        ),
                        trade_count={"sent": 0, "received": 0},
                        type="company",
                        identifiers=[
                            Identifier(
                                value="4346762",
                                type="usa_ny_dos_id",
                                label="Usa Ny Dos Id",
                            )
                        ],
                        addresses=[
                            "99 WASHINGTON AVE., SUITE 805A, ALBANY, NY, 12201",
                            "511 WEST 25TH STREET, SUITE # 701/7TH FLOOR, NEW YORK, NEW YORK, 10001",
                            "80 STATE STREET, ALBANY, NEW YORK, 12207-2543",
                        ],
                        countries=["USA"],
                        relationship_count={
                            "has_officer": 1,
                            "has_registered_agent": 2,
                            "linked_to": 2,
                        },
                        source_count={
                            "b4d06d4b77f51fab3c77c9653aabdda4": SourceCountInfo(
                                count=8,
                                label="USA New York Corporate Registry (Active Entities)",
                            )
                        },
                        risk={
                            "basel_aml": RiskData(
                                value=4.63,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                            "cpi_score": RiskData(
                                value=67.0,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                        },
                        user_attribute_count={},
                        user_record_count=0,
                        user_related_entities_count=0,
                        user_relationship_count={},
                        related_entities_count=3,
                        attribute_count={
                            "company_type": 1,
                            "name": 1,
                            "identifier": 1,
                            "country": 3,
                            "status": 1,
                            "address": 3,
                        },
                        reference_id="b4d06d4b77f51fab3c77c9653aabdda4/a80e7f4c-c219-437b-9941-32d89ea5885a/1560542045043:15d813b260619393762864f22d3c5b2d",
                    ),
                    editable=False,
                    matches={},
                )
            ],
        ),
        referenced_by=ReferencedBy(
            limit=1,
            size=QualifiedCount(
                count=216,
                qualifier="eq",
            ),
            next="Vk5NfGdsb2JhbF90cmFkZV90YV92bm18ZnwyMDI0LTAxLTAzfHtENjM0QjlCMS0zOUUyLTQyNzMtOEYzNUFFODExMzBFMThEN318MTcwNDI0MDAwMDAwMA",
            data=[
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{D634B9B1-39E2-4273-8F35AE81130E18D7}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BD634B9B1-39E2-4273-8F35AE81130E18D7%7D%2F1704240000000",
                    ),
                    type="mentions",
                )
            ],
        ),
    )
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EntityDetails, GetEntityResponse=GetEntityResponse)
update_forward_refs(EntityRelationships, GetEntityResponse=GetEntityResponse)
update_forward_refs(RelationshipData, GetEntityResponse=GetEntityResponse)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .currency import Currency
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class FinancialsProperties(UniversalBaseModel):
    assets: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total value of assets owned by a company
    """

    currency: typing.Optional[Currency] = pydantic.Field(default=None)
    """
    Reporting currency
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    as-of date
    """

    employees: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total employees
    """

    from_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    start date
    """

    liabilities: typing.Optional[float] = pydantic.Field(default=None)
    """
    Sum of the combined debts a company owes
    """

    net_income: typing.Optional[float] = pydantic.Field(default=None)
    """
    Company's earnings for a period after subtracting operating costs, taxes, and interest
    """

    paid_up_capital: typing.Optional[float] = pydantic.Field(default=None)
    """
    Paid-up capital is the capital already held by the company
    """

    registered_capital: typing.Optional[float] = pydantic.Field(default=None)
    """
    Registered capital is the maximum amount of share capital that a company is authorized to raise
    """

    revenue: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total amount of income generated by the sale of goods or services related to the company's primary operations
    """

    to_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    end date
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
import typing
import datetime as dt
from ..core.request_options import RequestOptions
from .types.usage_response import UsageResponse
from ..core.pydantic_utilities import parse_obj_as
from ..shared_errors.errors.bad_request import BadRequest
from ..shared_errors.types.bad_request_response import BadRequestResponse
from ..shared_errors.errors.unauthorized import Unauthorized
from ..shared_errors.types.unauthorized_response import UnauthorizedResponse
from ..shared_errors.errors.not_found import NotFound
from ..shared_errors.types.not_found_response import NotFoundResponse
from ..shared_errors.errors.rate_limit_exceeded import RateLimitExceeded
from ..shared_errors.types.rate_limit_response import RateLimitResponse
from ..shared_errors.errors.internal_server_error import InternalServerError
from ..shared_errors.types.internal_server_error_response import InternalServerErrorResponse
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from .types.history_response import HistoryResponse
from ..core.client_wrapper import AsyncClientWrapper


class InfoClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_usage(
        self,
        *,
        from_: typing.Optional[dt.date] = None,
        to: typing.Optional[dt.date] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UsageResponse:
        """
        The usage endpoint provides a simple interface to retrieve information on usage made by your API account. This includes both views per API path and credits consumed. The time period for the usage query is also specified in the response and whether or not this includes total usage.

        Parameters
        ----------
        from_ : typing.Optional[dt.date]
            An ISO 8601 encoded date string indicating the starting time period to obtain usage stats. In the format YYYY-MM-DD

        to : typing.Optional[dt.date]
            An ISO 8601 encoded date string indicating the ending time period to obtain usage stats. In the format YYYY-MM-DD

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UsageResponse
            OK

        Examples
        --------
        import datetime

        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.info.get_usage(
            from_=datetime.date.fromisoformat(
                "2023-01-15",
            ),
            to=datetime.date.fromisoformat(
                "2023-01-15",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/usage",
            method="GET",
            params={
                "from": str(from_) if from_ is not None else None,
                "to": str(to) if to is not None else None,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    UsageResponse,
                    parse_obj_as(
                        type_=UsageResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_history(
        self,
        *,
        events: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        from_: typing.Optional[dt.date] = None,
        to: typing.Optional[dt.date] = None,
        size: typing.Optional[int] = None,
        token: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HistoryResponse:
        """
        The history endpoint return a user's event history.

        Parameters
        ----------
        events : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            The type of events to filter on.

        from_ : typing.Optional[dt.date]
            An ISO 8601 encoded date string indicating the starting time period for the events. In the format YYYY-MM-DD

        to : typing.Optional[dt.date]
            An ISO 8601 encoded date string indicating the ending time period for the events. In the format YYYY-MM-DD

        size : typing.Optional[int]
            Size to limit number of events returned

        token : typing.Optional[str]
            Pagination token to retrieve the next page of results

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HistoryResponse
            OK

        Examples
        --------
        import datetime

        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.info.get_history(
            events="string",
            from_=datetime.date.fromisoformat(
                "2023-01-15",
            ),
            to=datetime.date.fromisoformat(
                "2023-01-15",
            ),
            size=1,
            token="string",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/history",
            method="GET",
            params={
                "events": events,
                "from": str(from_) if from_ is not None else None,
                "to": str(to) if to is not None else None,
                "size": size,
                "token": token,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    HistoryResponse,
                    parse_obj_as(
                        type_=HistoryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncInfoClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_usage(
        self,
        *,
        from_: typing.Optional[dt.date] = None,
        to: typing.Optional[dt.date] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UsageResponse:
        """
        The usage endpoint provides a simple interface to retrieve information on usage made by your API account. This includes both views per API path and credits consumed. The time period for the usage query is also specified in the response and whether or not this includes total usage.

        Parameters
        ----------
        from_ : typing.Optional[dt.date]
            An ISO 8601 encoded date string indicating the starting time period to obtain usage stats. In the format YYYY-MM-DD

        to : typing.Optional[dt.date]
            An ISO 8601 encoded date string indicating the ending time period to obtain usage stats. In the format YYYY-MM-DD

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UsageResponse
            OK

        Examples
        --------
        import asyncio
        import datetime

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.info.get_usage(
                from_=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                to=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/usage",
            method="GET",
            params={
                "from": str(from_) if from_ is not None else None,
                "to": str(to) if to is not None else None,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    UsageResponse,
                    parse_obj_as(
                        type_=UsageResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_history(
        self,
        *,
        events: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        from_: typing.Optional[dt.date] = None,
        to: typing.Optional[dt.date] = None,
        size: typing.Optional[int] = None,
        token: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HistoryResponse:
        """
        The history endpoint return a user's event history.

        Parameters
        ----------
        events : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            The type of events to filter on.

        from_ : typing.Optional[dt.date]
            An ISO 8601 encoded date string indicating the starting time period for the events. In the format YYYY-MM-DD

        to : typing.Optional[dt.date]
            An ISO 8601 encoded date string indicating the ending time period for the events. In the format YYYY-MM-DD

        size : typing.Optional[int]
            Size to limit number of events returned

        token : typing.Optional[str]
            Pagination token to retrieve the next page of results

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HistoryResponse
            OK

        Examples
        --------
        import asyncio
        import datetime

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.info.get_history(
                events="string",
                from_=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                to=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                size=1,
                token="string",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/history",
            method="GET",
            params={
                "events": events,
                "from": str(from_) if from_ is not None else None,
                "to": str(to) if to is not None else None,
                "size": size,
                "token": token,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    HistoryResponse,
                    parse_obj_as(
                        type_=HistoryResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .currency import Currency
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class SharesProperties(UniversalBaseModel):
    currency: typing.Optional[Currency] = pydantic.Field(default=None)
    """
    The currency of the monetary_value
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    as-of date
    """

    from_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    start date
    """

    monetary_value: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total monetary value of the shares
    """

    num_shares: typing.Optional[float] = pydantic.Field(default=None)
    """
    The number of shares held, issued, etc.
    """

    percentage: typing.Optional[float] = pydantic.Field(default=None)
    """
    The percentage of shares owned
    """

    to_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    end date
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string describing the type of shares (e.g., "Class B", "Protected cell shares")
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.pydantic_utilities import UniversalBaseModel
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
import typing
from .shortest_path_data import ShortestPathData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class ShortestPathResponse(UniversalBaseModel):
    """
    OK

    Examples
    --------
    from sayari.shared_types import (
        EntityDetails,
        Identifier,
        RelationshipInfo,
        RiskData,
        SourceCountInfo,
    )
    from sayari.traversal import (
        ShortestPathData,
        ShortestPathResponse,
        TraversalPath,
        TraversalRelationshipData,
    )

    ShortestPathResponse(
        entities=["H1y25N5ymnFyZ-q9Lpwm_g", "1nOeH5G2EhmRVtmeVqO2Lw"],
        data=[
            ShortestPathData(
                source="H1y25N5ymnFyZ-q9Lpwm_g",
                target=EntityDetails(
                    id="1nOeH5G2EhmRVtmeVqO2Lw",
                    label="Mr Thomas Bangalter",
                    degree=1,
                    entity_url="/v1/entity/1nOeH5G2EhmRVtmeVqO2Lw",
                    pep=False,
                    psa_count=0,
                    sanctioned=False,
                    closed=False,
                    trade_count={"sent": 0, "received": 0},
                    type="person",
                    identifiers=[
                        Identifier(
                            value="053673450003",
                            type="uk_person_number",
                            label="Uk Person Number",
                        ),
                        Identifier(
                            value="053673450002",
                            type="uk_person_number",
                            label="Uk Person Number",
                        ),
                    ],
                    addresses=[
                        "5TH FLOOR 104 OXFORD STREET, W1D 1LP, LONDON, UNITED KINGDOM",
                        "Oxford Street, London, W1D 1LP",
                        "8 AVENUE RACHEL, 75018, FRANCE",
                    ],
                    date_of_birth="1975-01",
                    countries=["FRA", "GBR"],
                    relationship_count={
                        "registered_agent_of": 1,
                        "shareholder_of": 1,
                        "director_of": 1,
                    },
                    source_count={
                        "4ea8bac1bed868e1510ffd21842e9551": SourceCountInfo(
                            count=28,
                            label="UK Persons with Significant Control",
                        ),
                        "ecdfb3f2ecc8c3797e77d5795a8066ef": SourceCountInfo(
                            count=17,
                            label="UK Corporate Registry",
                        ),
                    },
                    risk={
                        "basel_aml": RiskData(
                            value=3.67,
                            metadata={"country": ["GBR"]},
                            level="relevant",
                        ),
                        "cpi_score": RiskData(
                            value=71.0,
                            metadata={"country": ["FRA"]},
                            level="relevant",
                        ),
                    },
                    user_attribute_count={},
                    user_record_count=0,
                    user_related_entities_count=0,
                    user_relationship_count={},
                    related_entities_count=1,
                    attribute_count={
                        "name": 1,
                        "identifier": 2,
                        "additional_information": 2,
                        "country": 4,
                        "date_of_birth": 1,
                        "address": 5,
                    },
                    reference_id="ecdfb3f2ecc8c3797e77d5795a8066ef/03389614/1540252800000:9030330caf25555c42c0bc0d84ea4aa1",
                ),
                path=[
                    TraversalPath(
                        field="has_lawyer",
                        entity=EntityDetails(
                            id="xthsA_jQuKn3GW8-9ILQqg",
                            label="LAWRENCE E. APOLZON",
                            degree=179,
                            entity_url="/v1/entity/xthsA_jQuKn3GW8-9ILQqg",
                            pep=False,
                            psa_count=0,
                            sanctioned=False,
                            closed=False,
                            trade_count={"sent": 0, "received": 0},
                            type="person",
                            identifiers=[],
                            addresses=[
                                "Fross Zelnick Lehrman & Zissu, P.C., 866 United Nations Plaza, New York NY 10017",
                                "FROSS ZELNICK LEHRMAN & ZISSU, P.C., 4 TIMES SQUARE, 17TH FLOOR, NEW YORK, NY 10036",
                                "Fross Zelnick Lehrman & Zissu, P.C., 151 West 42nd Street, 17th Floor, New York, NY 10036",
                            ],
                            countries=["USA"],
                            relationship_count={"lawyer_of": 179},
                            source_count={
                                "ac1fa195f9cd4ccf657bca3c6db0bb19": SourceCountInfo(
                                    count=199,
                                    label="USA Patents and Trademark Office Trademark Applications",
                                )
                            },
                            risk={},
                            user_attribute_count={},
                            user_record_count=0,
                            user_related_entities_count=0,
                            user_relationship_count={},
                            related_entities_count=179,
                            attribute_count={"country": 1, "address": 5, "name": 1},
                            reference_id="ac1fa195f9cd4ccf657bca3c6db0bb19/76232419/1717632000000:6d0f0edbd065319df4be58c3bc7909f5",
                        ),
                        relationships={
                            "has_lawyer": TraversalRelationshipData(
                                values=[
                                    RelationshipInfo(
                                        record="ac1fa195f9cd4ccf657bca3c6db0bb19/76082348/1717632000000",
                                        acquisition_date="2024-06-06",
                                        attributes={},
                                    )
                                ],
                            )
                        },
                    )
                ],
            )
        ],
    )
    """

    entities: typing.List[str]
    data: typing.List[ShortestPathData]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EntityDetails, ShortestPathResponse=ShortestPathResponse)
update_forward_refs(EntityRelationships, ShortestPathResponse=ShortestPathResponse)
update_forward_refs(RelationshipData, ShortestPathResponse=ShortestPathResponse)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .project import Project
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class DeleteProjectResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project import DeleteProjectResponse, Project, ProjectCounts

    DeleteProjectResponse(
        data=Project(
            id="Gam5qG",
            label="Project Delta",
            archived=False,
            created="2024-04-24 13:43:56.546705+00",
            updated="2024-04-24 13:43:56.546705+00",
            counts=ProjectCounts(
                entity=2,
                graph=0,
                record=0,
                search=0,
            ),
        ),
    )
    """

    data: Project

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .additional_information_data import AdditionalInformationData
from .additional_information_info import AdditionalInformationInfo
from .additional_information_properties import AdditionalInformationProperties
from .address_data import AddressData
from .address_info import AddressInfo
from .address_properties import AddressProperties
from .address_type import AddressType
from .attribute_data import AttributeData
from .attribute_details import AttributeDetails
from .attributes import Attributes
from .both_identifier_types import BothIdentifierTypes
from .business_purpose_data import BusinessPurposeData
from .business_purpose_info import BusinessPurposeInfo
from .business_purpose_properties import BusinessPurposeProperties
from .business_purpose_standard import BusinessPurposeStandard
from .company_status import CompanyStatus
from .company_type_data import CompanyTypeData
from .company_type_info import CompanyTypeInfo
from .company_type_properties import CompanyTypeProperties
from .contact_data import ContactData
from .contact_info import ContactInfo
from .contact_properties import ContactProperties
from .contact_type import ContactType
from .country import Country
from .country_context import CountryContext
from .country_data import CountryData
from .country_info import CountryInfo
from .country_properties import CountryProperties
from .currency import Currency
from .date_of_birth_data import DateOfBirthData
from .date_of_birth_info import DateOfBirthInfo
from .date_of_birth_properties import DateOfBirthProperties
from .entities import Entities
from .finance_type import FinanceType
from .finances_data import FinancesData
from .finances_info import FinancesInfo
from .finances_properties import FinancesProperties
from .financials_data import FinancialsData
from .financials_info import FinancialsInfo
from .financials_properties import FinancialsProperties
from .gender import Gender
from .gender_data import GenderData
from .gender_info import GenderInfo
from .gender_properties import GenderProperties
from .generic_data import GenericData
from .generic_info import GenericInfo
from .generic_properties import GenericProperties
from .identifier_data import IdentifierData
from .identifier_info import IdentifierInfo
from .identifier_properties import IdentifierProperties
from .identifier_type import IdentifierType
from .language import Language
from .measurement_data import MeasurementData
from .measurement_info import MeasurementInfo
from .measurement_properties import MeasurementProperties
from .measurement_type import MeasurementType
from .monetary_value_context import MonetaryValueContext
from .monetary_value_data import MonetaryValueData
from .monetary_value_info import MonetaryValueInfo
from .monetary_value_properties import MonetaryValueProperties
from .name_context import NameContext
from .name_data import NameData
from .name_info import NameInfo
from .name_properties import NameProperties
from .person_status import PersonStatus
from .person_status_data import PersonStatusData
from .person_status_info import PersonStatusInfo
from .person_status_properties import PersonStatusProperties
from .position_data import PositionData
from .position_info import PositionInfo
from .position_properties import PositionProperties
from .relationships import Relationships
from .risk import Risk
from .risk_intelligence_data import RiskIntelligenceData
from .risk_intelligence_info import RiskIntelligenceInfo
from .risk_intelligence_properties import RiskIntelligenceProperties
from .shares_data import SharesData
from .shares_info import SharesInfo
from .shares_properties import SharesProperties
from .status_context import StatusContext
from .status_data import StatusData
from .status_info import StatusInfo
from .status_properties import StatusProperties
from .tag import Tag
from .translated_name_data import TranslatedNameData
from .translated_name_info import TranslatedNameInfo
from .translated_name_properties import TranslatedNameProperties
from .translation_context import TranslationContext
from .unit import Unit
from .weak_identifier_data import WeakIdentifierData
from .weak_identifier_info import WeakIdentifierInfo
from .weak_identifier_properties import WeakIdentifierProperties
from .weak_identifier_type import WeakIdentifierType

__all__ = [
    "AdditionalInformationData",
    "AdditionalInformationInfo",
    "AdditionalInformationProperties",
    "AddressData",
    "AddressInfo",
    "AddressProperties",
    "AddressType",
    "AttributeData",
    "AttributeDetails",
    "Attributes",
    "BothIdentifierTypes",
    "BusinessPurposeData",
    "BusinessPurposeInfo",
    "BusinessPurposeProperties",
    "BusinessPurposeStandard",
    "CompanyStatus",
    "CompanyTypeData",
    "CompanyTypeInfo",
    "CompanyTypeProperties",
    "ContactData",
    "ContactInfo",
    "ContactProperties",
    "ContactType",
    "Country",
    "CountryContext",
    "CountryData",
    "CountryInfo",
    "CountryProperties",
    "Currency",
    "DateOfBirthData",
    "DateOfBirthInfo",
    "DateOfBirthProperties",
    "Entities",
    "FinanceType",
    "FinancesData",
    "FinancesInfo",
    "FinancesProperties",
    "FinancialsData",
    "FinancialsInfo",
    "FinancialsProperties",
    "Gender",
    "GenderData",
    "GenderInfo",
    "GenderProperties",
    "GenericData",
    "GenericInfo",
    "GenericProperties",
    "IdentifierData",
    "IdentifierInfo",
    "IdentifierProperties",
    "IdentifierType",
    "Language",
    "MeasurementData",
    "MeasurementInfo",
    "MeasurementProperties",
    "MeasurementType",
    "MonetaryValueContext",
    "MonetaryValueData",
    "MonetaryValueInfo",
    "MonetaryValueProperties",
    "NameContext",
    "NameData",
    "NameInfo",
    "NameProperties",
    "PersonStatus",
    "PersonStatusData",
    "PersonStatusInfo",
    "PersonStatusProperties",
    "PositionData",
    "PositionInfo",
    "PositionProperties",
    "Relationships",
    "Risk",
    "RiskIntelligenceData",
    "RiskIntelligenceInfo",
    "RiskIntelligenceProperties",
    "SharesData",
    "SharesInfo",
    "SharesProperties",
    "StatusContext",
    "StatusData",
    "StatusInfo",
    "StatusProperties",
    "Tag",
    "TranslatedNameData",
    "TranslatedNameInfo",
    "TranslatedNameProperties",
    "TranslationContext",
    "Unit",
    "WeakIdentifierData",
    "WeakIdentifierInfo",
    "WeakIdentifierProperties",
    "WeakIdentifierType",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.pydantic_utilities import UniversalBaseModel
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
import typing
from .traversal_path import TraversalPath
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class ShortestPathData(UniversalBaseModel):
    source: str
    target: EntityDetails
    path: typing.List[TraversalPath]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EntityDetails, ShortestPathData=ShortestPathData)
update_forward_refs(EntityRelationships, ShortestPathData=ShortestPathData)
update_forward_refs(RelationshipData, ShortestPathData=ShortestPathData)



# This file was auto-generated by Fern from our API Definition.

from .bad_gateway_response import BadGatewayResponse
from .bad_request_response import BadRequestResponse
from .connection_error_response import ConnectionErrorResponse
from .internal_server_error_response import InternalServerErrorResponse
from .method_not_allowed_response import MethodNotAllowedResponse
from .not_acceptable_response import NotAcceptableResponse
from .not_found_response import NotFoundResponse
from .rate_limit_response import RateLimitResponse
from .unauthorized_response import UnauthorizedResponse

__all__ = [
    "BadGatewayResponse",
    "BadRequestResponse",
    "ConnectionErrorResponse",
    "InternalServerErrorResponse",
    "MethodNotAllowedResponse",
    "NotAcceptableResponse",
    "NotFoundResponse",
    "RateLimitResponse",
    "UnauthorizedResponse",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.country import Country
import pydantic
from ...generated_types.types.address_properties import AddressProperties
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ShipmentMetadata(UniversalBaseModel):
    arrival_country: typing.List[Country]
    jurisdiction: typing.List[Country]
    reference_id: str
    entity_id: str = pydantic.Field()
    """
    Unique identifier of the entity
    """

    departure_address: typing.Optional[AddressProperties] = None
    type: str
    sources: typing.List[str]
    departure_country: typing.List[Country]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...base_types.types.paginated_response import PaginatedResponse
import typing
from .source import Source
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ListSourcesResponse(PaginatedResponse):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.source import ListSourcesResponse, Source

    ListSourcesResponse(
        offset=0,
        limit=2,
        size=QualifiedCount(
            count=547,
            qualifier="eq",
        ),
        next=True,
        data=[
            Source(
                id="e85d865943ee6d8369307569d2ad9de0",
                label="Acuris Risk Intelligence Adverse Media Data",
                description="Contains PDFs and URLs to adverse media reporting for PEPs, SOEs, sanctioned entities, and entities linked to financial regulatory and law enforcement actions. Available for millions of entities from 'Acuris Risk Intelligence KYC6 (3rd Party Data)' in 'Records' section.",
                country="XXX",
                region="international_(multi-region_coverage)",
                date_added="2022-04-11",
                source_type="adverse_media_/_negative_news_data",
                record_type="adverse_media_record",
                structure="unstructured",
                source_url="https://www.acurisriskintelligence.com/",
                pep=False,
                watchlist=False,
            ),
            Source(
                id="a8c6ee1cd4dfc952105ee8c0e4836f08",
                label="Acuris Risk Intelligence KYC6 (3rd Party Data)",
                description="Contains profiles of PEPs, sanctioned entities, SOEs, and entities linked to financial regulatory and law enforcement actions from hundreds of international watchlists. Provides identifying information on individuals and companies as available.",
                country="XXX",
                region="international_(multi-region_coverage)",
                date_added="2022-02-09",
                source_type="risk_intelligence_data",
                record_type="risk_intelligence_record",
                structure="unstructured",
                source_url="https://www.acurisriskintelligence.com/",
                pep=False,
                watchlist=False,
            ),
        ],
    )
    """

    offset: int
    next: bool
    data: typing.List[Source]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...base_types.types.paginated_response import PaginatedResponse
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class RecordReferences(PaginatedResponse):
    next: bool
    offset: int
    data: typing.Optional[typing.Any] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
